##  Reference Catalog
The reference catalog provides reference data for business capabilities, applications, IT components, and tech categories, which enables you to set up and maintain your inventory more efficiently. To learn more about each data type and fact sheet attributes, see [Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "The reference catalog provides reference data for business capabilities, applications, IT components, and tech categories, which enables you to set up and maintain your inventory more efficiently.").
Guides | Description
---|---
[Business Capabilities in the Reference Catalog](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "Import business capabilities from best-practice, industry-specific business capabilities and customize them to suit your organization’s needs.") | The reference catalog provides industry-specific business capability maps for import. When catalog items are imported, corresponding business capability fact sheets are automatically created in your workspace and linked to the catalog.
[Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for application fact sheets, you can increase standardization and data quality, as well as set relations to other fact sheets for best-practice modeling.") | The reference catalog offers standardized data for application fact sheets. By using reference data for application fact sheets, you can increase standardization and data quality, as well as set relations to other fact sheets for best-practice modeling.
[IT Components in the Reference Catalog](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for IT component fact sheets, you can increase standardization and data quality, set relations to other fact sheets for best-practice modeling, as well as manage technology obsolescence risks by using vendor lifecycle information.") | By using reference data for IT component fact sheets, you can increase standardization and data quality, set relations to other fact sheets for best-practice modeling, as well as manage technology obsolescence risks by using vendor lifecycle information.
[Tech Categories in the Reference Catalog](https://help.sap.com/docs/leanix/ea/tech-categories-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "Tech categories in the reference catalog enable you to adopt the Technology Business Management \(TBM\) Taxonomy.") | Tech categories in the reference catalog are based on the TBM Taxonomy. You can import tech categories into your workspace and customize them to your needs.


YesNo
Send
